/*
 * Copyright (C) 2004-2006 Atmel Corporation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <common.h>

#include <asm/io.h>
#include <asm/arch/clk.h>
#include <asm/arch/memory-map.h>
#include <asm/arch/at91sam9260.h>
#include <asm/arch/gpio.h>
#include <asm/arch/at91_pmc.h>
#include <asm/arch/io.h>

# define USART_ID	4

#include "atmel_usart.h"

DECLARE_GLOBAL_DATA_PTR;
int CONSOLE_ID = 0;

u32 getbase(int id)
{
	if(id == 1) {return USART1_BASE;} 
	if(id == 2) {return USART0_BASE;} 
	if(id == 3) {return USART2_BASE;} 
	if(id == 4) {return USART3_BASE;} 
	return USART4_BASE; 
}

#define USART_BASE(id) getbase(id)
	

//(id == 1) ? USART1_BASE : ((id == 2) ? USART0_BASE : ((id == 3) ? USART2_BASE : ((id == 4) ? USART3_BASE : USART4_BASE)))
	

/* Register access macros */
#define usart3_readl(id,reg)				\
	readl((void *) USART_BASE(id) + USART3_##reg)
#define usart3_writel(id,reg,value)			\
	writel((value),(void *) USART_BASE(id) + USART3_##reg)
	
void serial_setbrg(void)
{
	unsigned long divisor;
	unsigned long usart_hz;

	/*
	 *              Master Clock
	 * Baud Rate = --------------
	 *                16 * CD
	 */
	usart_hz = get_usart_clk_rate(USART_ID);
	divisor = (usart_hz / 16 + gd->baudrate / 2) / gd->baudrate;
	usart3_writel(CONSOLE_ID,BRGR, USART3_BF(CD, divisor));
}

#if CONFIG_SWITCH_CONSOLE
void serial_init_peripheral(void){
	char *s = NULL;	
	s = getenv("console");
	if(!strcmp(s,"ttyS2")) {
		at91_set_A_periph(AT91_PIN_PB4, 1);		/* TXD0 */
		at91_set_A_periph(AT91_PIN_PB5, 0);		/* RXD0 */
		at91_sys_write(AT91_PMC_PCER, 1 << AT91SAM9260_ID_US0);
		CONSOLE_ID = 2;
	}
	else if(!strcmp(s,"ttyS1")) {
		at91_set_A_periph(AT91_PIN_PB6, 1);		/* TXD1 */
		at91_set_A_periph(AT91_PIN_PB7, 0);		/* RXD1 */
		at91_sys_write(AT91_PMC_PCER, 1 << AT91SAM9260_ID_US1);
		CONSOLE_ID = 1;
	}
	else if(!strcmp(s,"ttyS3")) {
		at91_set_A_periph(AT91_PIN_PB8, 1);		/* TXD2 */
		at91_set_A_periph(AT91_PIN_PB9, 0);		/* RXD2 */
		at91_sys_write(AT91_PMC_PCER, 1 << AT91SAM9260_ID_US2);
		CONSOLE_ID = 3;
	}
	else if(!strcmp(s,"ttyS4")) {
		at91_set_A_periph(AT91_PIN_PB10, 1);		/* TXD2 */
		at91_set_A_periph(AT91_PIN_PB11, 0);		/* RXD2 */
		at91_sys_write(AT91_PMC_PCER, 1 << AT91SAM9260_ID_US3);	
		CONSOLE_ID = 4;
	}
}
#endif
int serial_init(void)
{
#if CONFIG_SWITCH_CONSOLE
	serial_init_peripheral();
#else
	setenv("console", "ttyS0");
#endif
	usart3_writel(CONSOLE_ID,CR, USART3_BIT(RSTRX) | USART3_BIT(RSTTX));

	serial_setbrg();

	usart3_writel(CONSOLE_ID,CR, USART3_BIT(RXEN) | USART3_BIT(TXEN));
	usart3_writel(CONSOLE_ID,MR, (USART3_BF(USART_MODE, USART3_USART_MODE_NORMAL)
			   | USART3_BF(USCLKS, USART3_USCLKS_MCK)
			   | USART3_BF(CHRL, USART3_CHRL_8)
			   | USART3_BF(PAR, USART3_PAR_NONE)
			   | USART3_BF(NBSTOP, USART3_NBSTOP_1)));
	
	return 0;
}

void serial_putc(char c)
{
	if (c == '\n')
		serial_putc('\r');

	while (!(usart3_readl(CONSOLE_ID,CSR) & USART3_BIT(TXRDY))) ;
	usart3_writel(CONSOLE_ID,THR, c);
}

void serial_puts(const char *s)
{
	while (*s)
		serial_putc(*s++);
}

int serial_getc(void)
{
	while (!(usart3_readl(CONSOLE_ID,CSR) & USART3_BIT(RXRDY))) ;
	return usart3_readl(CONSOLE_ID,RHR);
}

int serial_tstc(void)
{
	return (usart3_readl(CONSOLE_ID,CSR) & USART3_BIT(RXRDY)) != 0;
}
