/*
 * (C) Copyright 2007-2008
 * Stelian Pop <stelian.pop@leadtechdesign.com>
 * Lead Tech Design <www.leadtechdesign.com>
 *
 * Configuation settings for the AT91SAM9263EK board.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#ifndef __CONFIG_H
#define __CONFIG_H

#define CONFIG_NAME 		"PAC-4000"

/* ARM asynchronous clock */
#define AT91_MASTER_CLOCK	132096000	/* peripheral */	
#define CONFIG_SYS_AT91_PLLB	0x107c3e18	/* PLLB settings for USB */
#define CONFIG_SYS_HZ		1000000		/* 1us resolution */
#define CFG_HZ			CONFIG_SYS_HZ	/* 1us resolution */

#define AT91_SLOW_CLOCK		32768	/* slow clock */

#define CONFIG_ARM926EJS	1	/* This is an ARM926EJS Core	*/
#define CONFIG_MATRIX504	1	/* It's an Atmel AT91SAM9263 SoC*/
#define CONFIG_MATRIX518	1	/* It's an Atmel AT91SAM9263 SoC*/
#undef CONFIG_USE_IRQ			/* we don't need IRQ/FIQ stuff	*/

#define CONFIG_CMDLINE_TAG	1	/* enable passing of ATAGs	*/
#define CONFIG_SETUP_MEMORY_TAGS 1
#define CONFIG_INITRD_TAG	1

#define CONFIG_SKIP_LOWLEVEL_INIT
#define CONFIG_SKIP_RELOCATE_UBOOT


/*
 * Hardware drivers
 */
#define CONFIG_ATMEL_USART	1
#undef CONFIG_USART0
#undef CONFIG_USART1
#undef CONFIG_USART2
//#define CONFIG_USART3		1	/* USART 3 is DBGU */


#define CONFIG_SYS_WHITE_ON_BLACK		1
#define CONFIG_SYS_CONSOLE_IS_IN_ENV		1
#define CONFIG_BOOTDELAY	3

/*
 * BOOTP options
 */
#define CONFIG_BOOTP_BOOTFILESIZE	1
#define CONFIG_BOOTP_BOOTPATH		1
#define CONFIG_BOOTP_GATEWAY		1
#define CONFIG_BOOTP_HOSTNAME		1

/*
 * Artila Ace Set
 */
//#define CONFIG_SYS_NAND_YAFFS_WRITE	1
//#define CONFIG_YAFFS2			1
//#define CONFIG_CMD_YAFFS2		1
//#define CONFIG_RESET_PHY_R		1
#define CONFIG_SYS_CONSOLE_INFO_QUIET	1
#define CONFIG_ETHADDR				00:13:48:00:00:00

#define CONFIG_OVERWRITE_ETHADDR_ONCE		1


#define CONFIG_64MB			1
#define CONFIG_VERSION_VARIABLE		1

/*
 * Command line configuration.
 */
#include <config_cmd_default.h>
#undef CONFIG_CMD_BDI
#define CONFIG_CMD_IMI
#undef CONFIG_CMD_AUTOSCRIPT
#undef CONFIG_CMD_FPGA
#undef CONFIG_CMD_LOADS
#undef CONFIG_CMD_IMLS

#define CONFIG_CMD_PING		1
#define CONFIG_CMD_DHCP		1
#define CONFIG_CMD_NAND		1
#define CONFIG_CMD_USB		1

/* SDRAM */
#define CONFIG_NR_DRAM_BANKS		1
#define PHYS_SDRAM			0x20000000
#define PHYS_SDRAM_SIZE			0x08000000//0x04000000	/* 64 megs */

/* DataFlash */
#define CONFIG_HAS_DATAFLASH		1
#define CONFIG_SYS_SPI_WRITE_TOUT		(5*CONFIG_SYS_HZ)
#define CONFIG_SYS_MAX_DATAFLASH_BANKS		1
#define CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS1	0xD0000000	/* CS1 */
#define AT91_SPI_CLK			15000000
#define DATAFLASH_TCSS			(0x22 << 16)
#define DATAFLASH_TCHS			(0x1 << 24)

/* NOR flash, if populated */
#define CONFIG_SYS_NO_FLASH			1

/* NAND flash */
#define CONFIG_SYS_MAX_NAND_DEVICE		1
#define CONFIG_SYS_NAND_BASE			0x40000000
#define CONFIG_SYS_NAND_DBW_8			1

/* Ethernet */
#define CONFIG_MACB			1
#define CONFIG_RMII			1
#define CONFIG_NET_MULTI		1
#define CONFIG_NET_RETRY_COUNT		50//Ace
#define CONFIG_RESET_PHY_R		1

/* Ethernet */
#ifdef CONFIG_SYS_USE_NANDFLASH

#define  CONFIG_SWITCH_CONSOLE 	1

#define CONFIG_ETH1ADDR			00:13:48:00:00:01
#define CONFIG_DRIVER_DM9000 		1
#define CONFIG_DM9000_BASE 		0x70000000
#define DM9000_IO CONFIG_DM9000_BASE
#define DM9000_DATA (CONFIG_DM9000_BASE+4)
#define CONFIG_DM9000_NO_SROM		1
#define CONFIG_HAS_ETH1			1

#endif

#include "version.h"

/* USB */
#define CONFIG_USB_OHCI_NEW		1
#define CONFIG_DOS_PARTITION		1
#define CONFIG_SYS_USB_OHCI_CPU_INIT		1
#define CONFIG_SYS_USB_OHCI_REGS_BASE		0x00a00000	/* AT91SAM9263_UHP_BASE */
#define CONFIG_SYS_USB_OHCI_SLOT_NAME		"matrix504"
#define CONFIG_SYS_USB_OHCI_MAX_ROOT_PORTS	2
#define CONFIG_USB_STORAGE		1
#define CONFIG_CMD_FAT			1

#define CONFIG_SYS_LOAD_ADDR			0x22000000	/* load address */

#define CONFIG_SYS_MEMTEST_START		PHYS_SDRAM
#define CONFIG_SYS_MEMTEST_END			0x27e00000//0x23e00000


#ifdef CONFIG_SYS_USE_DATAFLASH

/* bootstrap + u-boot + env + linux in dataflash on CS0 */
#define CONFIG_ENV_IS_IN_DATAFLASH	1
#define CONFIG_ENV_OFFSET		0x4200
//#define CONFIG_ENV_ADDR_REDUND          0x6300
#define CONFIG_ENV_ADDR			(CONFIG_SYS_DATAFLASH_LOGIC_ADDR_CS1 + CONFIG_ENV_OFFSET)
#define CONFIG_ENV_SIZE			0x4200


#define CONFIG_BOOTCOMMAND		"dboot"
#define CONFIG_BOOTARGS		"console=ttyS0,115200 "			\
				"mtdparts=atmel_nand:128k(Bootstrap)ro"  \
				",256k(Uboot)ro,128k(Uboot-Env)ro,2560k(Kernel)ro," \
				"-(root) rw2 ubi.mtd=4 root=/dev/ram0 "\
				"initrd=0x20800000,8192000 "  \
				"rootfstype=cramfs"
#define CONFIG_DBARGS           "setenv bootargs " \
				"console=ttyS0,115200 "			\
				"mtdparts=atmel_nand:128k(Bootstrap)ro"  \
				",256k(Uboot)ro,128k(Uboot-Env)ro,2560k(Kernel)ro," \
				"-(root) rw2 ubi.mtd=4 root=/dev/ram0 "\
				"initrd=0x20800000,8192000 "  \
				"rootfstype=cramfs"

#else /* CONFIG_SYS_USE_NANDFLASH */

/* bootstrap + u-boot + env + linux in nandflash */
#define CONFIG_ENV_IS_IN_NAND		1
#define CONFIG_ENV_OFFSET		0x60000
//#define CONFIG_ENV_OFFSET_REDUND	0x60000
#define CONFIG_ENV_SIZE			0x20000		/* 1 sector = 128 kB */
#define CONFIG_BOOTCOMMAND		"nboot 22000000 0 80000 ; bootm 22000000"
#define CONFIG_BOOTARGS		"console=ttyS0,115200 "			\
				"mtdparts=atmel_nand:128k(Bootstrap)ro"  \
				",256k(Uboot)ro,128k(Uboot-Env)ro,2560k(Kernel)ro," \
				"-(root) rw2 ubi.mtd=4 root=ubi0:rootfs "\
				"initrd=0x20800000,8192000 "  \
				"rootfstype=ubifs"
#define CONFIG_DBARGS           "setenv bootargs " \
				"console=ttyS0,115200 "			\
				"mtdparts=atmel_nand:128k(Bootstrap)ro"  \
				",256k(Uboot)ro,128k(Uboot-Env)ro,2560k(Kernel)ro," \
				"-(root) rw2 ubi.mtd=4 root=/dev/ram0 "\
				"initrd=0x20800000,8192000 "  \
				"rootfstype=cramfs"
#endif

#define CONFIG_BAUDRATE		115200
#define CONFIG_SYS_BAUDRATE_TABLE	{115200 , 19200, 38400, 57600, 9600 }

#define CONFIG_SYS_PROMPT		"Artila> "
#define CONFIG_SYS_CBSIZE		512//256
#define CONFIG_SYS_MAXARGS		16
#define CONFIG_SYS_PBSIZE		(CONFIG_SYS_CBSIZE + sizeof(CONFIG_SYS_PROMPT) + 16)
#define CONFIG_SYS_LONGHELP		1
#define CONFIG_CMDLINE_EDITING	1

#define ROUND(A, B)		(((A) + (B)) & ~((B) - 1))
/*
 * Size of malloc() pool
 */
#define CONFIG_SYS_MALLOC_LEN		ROUND(3 * CONFIG_ENV_SIZE + 128*1024, 0x1000)
#define CONFIG_SYS_GBL_DATA_SIZE	128	/* 128 bytes for initial data */

#define CONFIG_STACKSIZE	(32*1024)	/* regular stack */

#ifdef CONFIG_USE_IRQ
#error CONFIG_USE_IRQ not supported
#endif

#endif
